==> kubernetes-model-resource-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/PodSchedulingFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSchedulingFluent<A extends PodSchedulingFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public PodSchedulingFluent.MetadataNested<A> withNewMetadata();
  public PodSchedulingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public PodSchedulingFluent.MetadataNested<A> editMetadata();
  public PodSchedulingFluent.MetadataNested<A> editOrNewMetadata();
  public PodSchedulingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSchedulingSpec getSpec();
  public PodSchedulingSpec buildSpec();
  public A withSpec(PodSchedulingSpec spec);
  public Boolean hasSpec();
  public PodSchedulingFluent.SpecNested<A> withNewSpec();
  public PodSchedulingFluent.SpecNested<A> withNewSpecLike(PodSchedulingSpec item);
  public PodSchedulingFluent.SpecNested<A> editSpec();
  public PodSchedulingFluent.SpecNested<A> editOrNewSpec();
  public PodSchedulingFluent.SpecNested<A> editOrNewSpecLike(PodSchedulingSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSchedulingStatus getStatus();
  public PodSchedulingStatus buildStatus();
  public A withStatus(PodSchedulingStatus status);
  public Boolean hasStatus();
  public PodSchedulingFluent.StatusNested<A> withNewStatus();
  public PodSchedulingFluent.StatusNested<A> withNewStatusLike(PodSchedulingStatus item);
  public PodSchedulingFluent.StatusNested<A> editStatus();
  public PodSchedulingFluent.StatusNested<A> editOrNewStatus();
  public PodSchedulingFluent.StatusNested<A> editOrNewStatusLike(PodSchedulingStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<PodSchedulingFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,PodSchedulingSpecFluent<PodSchedulingFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,PodSchedulingStatusFluent<PodSchedulingFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/PodSchedulingFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSchedulingFluent<A extends PodSchedulingFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public PodSchedulingFluent.MetadataNested<A> withNewMetadata();
  public PodSchedulingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public PodSchedulingFluent.MetadataNested<A> editMetadata();
  public PodSchedulingFluent.MetadataNested<A> editOrNewMetadata();
  public PodSchedulingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSchedulingSpec getSpec();
  public PodSchedulingSpec buildSpec();
  public A withSpec(PodSchedulingSpec spec);
  public Boolean hasSpec();
  public PodSchedulingFluent.SpecNested<A> withNewSpec();
  public PodSchedulingFluent.SpecNested<A> withNewSpecLike(PodSchedulingSpec item);
  public PodSchedulingFluent.SpecNested<A> editSpec();
  public PodSchedulingFluent.SpecNested<A> editOrNewSpec();
  public PodSchedulingFluent.SpecNested<A> editOrNewSpecLike(PodSchedulingSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSchedulingStatus getStatus();
  public PodSchedulingStatus buildStatus();
  public A withStatus(PodSchedulingStatus status);
  public Boolean hasStatus();
  public PodSchedulingFluent.StatusNested<A> withNewStatus();
  public PodSchedulingFluent.StatusNested<A> withNewStatusLike(PodSchedulingStatus item);
  public PodSchedulingFluent.StatusNested<A> editStatus();
  public PodSchedulingFluent.StatusNested<A> editOrNewStatus();
  public PodSchedulingFluent.StatusNested<A> editOrNewStatusLike(PodSchedulingStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<PodSchedulingFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,PodSchedulingSpecFluent<PodSchedulingFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,PodSchedulingStatusFluent<PodSchedulingFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
